@@ -190,6 +190,40 @@ class GymBobApp(Gtk.Application):
         # Button actions
         # --------------
 
+        back_10_button_action = Gio.SimpleAction.new('back_10_button', None)
+        back_10_button_action.connect(
+            'activate',
+            self.on_button_adjust_timer,
+            -10,
+        )
+        self.add_action(back_10_button_action)
+
+        back_60_button_action = Gio.SimpleAction.new('back_60_button', None)
+        back_60_button_action.connect(
+            'activate',
+            self.on_button_adjust_timer,
+            -60,
+        )
+        self.add_action(back_60_button_action)
+
+        forward_60_button_action \
+        = Gio.SimpleAction.new('forward_60_button', None)
+        forward_60_button_action.connect(
+            'activate',
+            self.on_button_adjust_timer,
+            60,
+        )
+        self.add_action(forward_60_button_action)
+
+        forward_10_button_action \
+        = Gio.SimpleAction.new('forward_10_button', None)
+        forward_10_button_action.connect(
+            'activate',
+            self.on_button_adjust_timer,
+            10,
+        )
+        self.add_action(forward_10_button_action)
+
         start_button_action = Gio.SimpleAction.new('start_button', None)
         start_button_action.connect('activate', self.on_button_start)
         self.add_action(start_button_action)
@@ -241,8 +275,6 @@ class GymBobApp(Gtk.Application):
 
         # Set the directory in which sound files are stored
         # When installed via PyPI, the files are moved to ../gymbob/sounds
-        # When installed via a Debian/RPM package, the files are moved to
-        #   /usr/share/gymbob/sounds
         sound_dir_list = []
         sound_dir_list.append(
             os.path.abspath(
@@ -259,12 +291,6 @@ class GymBobApp(Gtk.Application):
             ),
         )
 
-        sound_dir_list.append(
-            os.path.join(
-                '/', 'usr', 'share', __main__.__packagename__, 'sounds',
-            )
-        )
-
         for sound_dir_path in sound_dir_list:
             if os.path.isdir(sound_dir_path):
                 self.sound_dir = sound_dir_path
@@ -454,6 +480,8 @@ class GymBobApp(Gtk.Application):
 
         """Called periodically by self.script_timer_callback().
 
+        Is also called by editwin.ProgEditWin.on_button_test_clicked().
+
         If a sound file has been set, play it (unless sound is muted).
         """
 
@@ -478,10 +506,16 @@ class GymBobApp(Gtk.Application):
     # (Timers)
 
 
-    def script_timer_callback(self):
+    def script_timer_callback(self, force_flag=False):
 
         """Called by GObject timer created by self.start(), ten times a second.
 
+        Args:
+
+            force_flag (bool): True when called by self.on_button_adjust_timer,
+                in which case we update the contents of textviews even when
+                the clock is not running
+
         Returns:
 
             1 to keep the timer going, or None to halt it
@@ -491,12 +525,17 @@ class GymBobApp(Gtk.Application):
         # (Use the same time value to update all main window widgets)
         current_time = time.time()
 
-        # If the programme is running...
-        if self.clock_running_flag:
+        # If the programme is running (or if the clock has been regressed/
+        #   advanced)...
+        if self.clock_running_flag or force_flag:
 
             # Update the contents of textviews in the main window
             # (De)sensitise menu items and/or buttons
-            clock_time = current_time - self.clock_start_time
+            if not self.clock_running_flag:
+                clock_time = self.clock_stop_time - self.clock_start_time
+            else:
+                clock_time = current_time - self.clock_start_time
+
             self.main_win_obj.update_clock_textview(clock_time)
 
             if self.current_prog_next_update_time is not None \
@@ -543,6 +582,40 @@ class GymBobApp(Gtk.Application):
     # (Widgets)
 
 
+    def on_button_adjust_timer(self, action, par, seconds):
+
+        """Called from a callback in self.do_startup().
+
+        Starts the clock.
+
+        Args:
+
+            action (Gio.SimpleAction): Object generated by Gio
+
+            par (None): Ignored
+
+            seconds (int): The number of seconds with which to adjust the
+                timer; a negative number to regress the timer, a positive
+                number to advance it
+
+        """
+
+        # First sanity check
+        if not self.clock_start_time:
+            return
+
+        # Second sanity check: don't let the timer go below 0
+        new_time = self.clock_start_time - seconds
+        if new_time > time.time():
+            return
+
+        # All good, we can adjust the timer
+        self.clock_start_time = new_time
+        # Artificially call the timer callback to update the timer values
+        #   visible in the main window
+        self.script_timer_callback(True)
+
+
     def on_button_start(self, action, par):
 
         """Called from a callback in self.do_startup().
@@ -929,3 +1002,8 @@ class GymBobApp(Gtk.Application):
             self.mute_sound_flag = False
         else:
             self.mute_sound_flag = True
+
+
+    def set_sound_file(self, filename):
+
+        self.sound_file = filename
